@@ -8,6 +8,9 @@ import shutil
 import urllib
 
 from .interfaces import SearchEngineInterface
+from .utilities import configPath
+
+import datetime
 
 ## -------------------------------------------
 ## Java-Friendly datetime string format
@@ -137,17 +140,20 @@ class Solr(SearchEngineInterface):
         name = self.name
         path = self.root
 
-
         if not self.indexExists(name):
-            try:
 
+            try:
                 if not os.path.isdir(self.solr_home):
                     #Create the directories to hold the Solr conf and data
-                    module_dir = os.path.dirname(os.path.abspath(__file__))
-                    pathlen = module_dir.rfind('/')+1
-                    graph_source = module_dir[0:pathlen] + '/solr_home/configsets/skipchunk-'+self.kind+'-configset'
+                    graph_source = configPath('skipchunk/solr_home/configsets/skipchunk-'+self.kind+'-configset')
                     shutil.copytree(graph_source,self.solr_home)
 
+            except:
+                message = 'DISK ERROR! Could not find the schema at ' + graph_source
+                raise ValueError(message)            
+
+            try:
+
                 #Create the core in solr
                 uri = host + 'admin/cores?action=CREATE&name='+name+'&instanceDir='+self.solr_home+'/conf&config=solrconfig.xml&dataDir='+self.solr_home+'/data'
                 r = requests.get(uri)
